import { WelcomeComponent } from './components/welcome/welcome.component';
import { RouterModule, Routes } from '@angular/router';
import { OrganizationsComponent } from './components/organizations/list/organizations.component';
import { NgModule } from '@angular/core';
import { OrganizationDetailComponent } from './components/organizations/detail/organization-detail.component';
import { OrganizationFormComponent } from './components/organizations/edit/organization-form.component';
import { ResourcesComponent } from './components/resources/list/resources.component';
import { ResourceFormComponent } from './components/resources/edit/resource-form.component';
import { ResourceDetailComponent } from './components/resources/detail/resource-detail.component';
import { FormatsComponent, FormatDetailComponent, FormatFormComponent } from './components';
import { AuthenticatedGuard } from './user/guards/authenticated.guard';

const appRoutes: Routes = [
  {
    path: '',
    component: WelcomeComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Bienvenue',
    },
  },
  {
    path: 'organizations',
    component: OrganizationsComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Organisations',
    },
  },
  {
    path: 'organizations/new',
    component: OrganizationFormComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Nouvelle organisation',
    },
  },
  {
    path: 'organizations/:id/edit',
    component: OrganizationFormComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Modifier l\'organisation',
    },
  },
  {
    path: 'organizations/:id',
    component: OrganizationDetailComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Organisation',
    },
  },
  {
    path: 'resources',
    component: ResourcesComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Ressources',
    },
  },
  {
    path: 'resources/new',
    component: ResourceFormComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Nouvelle ressource',
    },
  },
  {
    path: 'resources/:id/edit',
    component: ResourceFormComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Modifier la ressource',
    },
  },
  {
    path: 'resources/:id',
    component: ResourceDetailComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Ressource',
    },
  },
  {
    path: 'formats',
    component: FormatsComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Formats',
    },
  },
  {
    path: 'formats/new',
    component: FormatFormComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Nouveau format',
    },
  },
  {
    path: 'formats/:id/edit',
    component: FormatFormComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Modifier le format',
    },
  },
  {
    path: 'formats/:id',
    component: FormatDetailComponent,
    canActivate: [AuthenticatedGuard],
    data: {
      title: 'Format',
    },
  },
];

@NgModule({
  imports: [
    RouterModule.forRoot(appRoutes),
  ],
  exports: [
    RouterModule,
  ],
})
export class AppRoutingModule { }
