import { Component, OnInit } from '@angular/core';
import { FormGroup, FormBuilder, Validators } from '@angular/forms';
import { Router } from '@angular/router';
import { HttpErrorResponse } from '@angular/common/http';
import { UserService } from '../../services';

@Component({
  selector: 'app-login',
  templateUrl: './login.component.html',
  styleUrls: ['./login.component.scss'],
})
export class LoginComponent implements OnInit {

  form: FormGroup;
  errorStatus: number = null;

  constructor(
    private _fb: FormBuilder,
    private _userService: UserService,
    private _router: Router,
  ) {

    this.form = this._fb.group({
      username: ['', [Validators.required, Validators.email]],
      password: ['', Validators.required],
    });
  }

  ngOnInit() { }

  login() {
    if (this.form.valid) {
      this.form.disable();
      this._userService.login(this.form.value).subscribe(
        (res) => {
          this.form.enable();
          this.errorStatus = null;
          this._router.navigate(['/']);
        },
        (err) => {
          if (err instanceof HttpErrorResponse) {
            this.errorStatus = err.status;
          } else {
            this.errorStatus = 500;
          }
          this.form.enable();
        },
      );
    } else {
      this.errorStatus = 400;
    }
  }

  closeErrorMessage() {
    this.errorStatus = null;
  }

  fieldIsValid(field: string) {
    return (this.form.get(field).touched) && this.form.get(field).valid;
  }

  fieldIsInvalid(field: string) {
    return (this.form.get(field).touched) && this.form.get(field).invalid;
  }

  get username() { return this.form.get('username'); }
  get password() { return this.form.get('password'); }

  get formDisabled() {
    return this.form.disabled;
  }

}
